from sqlalchemy import Column, Integer, String, DateTime, ForeignKey
from sqlalchemy.orm import relationship
from omop_cdm_graphql.database import metadata

from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base(metadata=metadata)


class Person(Base):
    __tablename__ = "person"
    person_id = Column(Integer, primary_key=True, index=True)
    gender_concept_id = Column(Integer)
    birth_datetime = Column(DateTime)
    observations = relationship("Observation", back_populates="person")
    conditions = relationship("ConditionOccurrence", back_populates="person")


class Observation(Base):
    __tablename__ = "observation"
    observation_id = Column(Integer, primary_key=True, index=True)
    person_id = Column(Integer, ForeignKey("person.person_id"))
    observation_concept_id = Column(Integer)
    observation_date = Column(DateTime)
    person = relationship("Person", back_populates="observations")


class ConditionOccurrence(Base):
    __tablename__ = "condition_occurrence"
    condition_occurrence_id = Column(Integer, primary_key=True, index=True)
    person_id = Column(Integer, ForeignKey("person.person_id"))
    condition_concept_id = Column(Integer)
    condition_start_date = Column(DateTime)
    person = relationship("Person", back_populates="conditions")



import os
import pathlib
import sys
import yaml

from sqlalchemy import create_engine, MetaData
from sqlalchemy.orm import sessionmaker

from omop_cdm_graphql.file_utils import check_infile_status
from omop_cdm_graphql import constants

current_working_directory = os.getcwd()
config_file = os.path.join(current_working_directory, "config.yaml")
check_infile_status(config_file)

print(f"Will load contents of config file '{config_file}'")
config = yaml.safe_load(pathlib.Path(config_file).read_text())


database_file = config.get("database_file", None)
if not database_file:
    database_file = constants.DEFAULT_DATABASE_FILE
    print(
        f"Database file not specified in configuration file '{config_file}' - setting default '{database_file}'"
    )

DATABASE_URL = f"sqlite:///{database_file}"
engine = create_engine(DATABASE_URL, echo=True)
SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)
metadata = MetaData()


def get_db():
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()


# Create tables (run once)
metadata.create_all(engine)



import os
import pathlib
import uvicorn
import yaml

from fastapi import FastAPI
from strawberry.fastapi import GraphQLRouter

from omop_cdm_graphql.schema import schema
from omop_cdm_graphql.file_utils import check_infile_status
from omop_cdm_graphql import constants


current_working_directory = os.getcwd()
config_file = os.path.join(current_working_directory, "config.yaml")

check_infile_status(config_file)

print(f"Will load contents of config file '{config_file}'")
config = yaml.safe_load(pathlib.Path(config_file).read_text())

host = config.get("host", None)
port = config.get("port", None)

if not host:
    host = constants.DEFAULT_HOST
    print(f"Host not specified in configuration file '{config_file}' - setting default '{host}'")
if not port:
    port = constants.DEFAULT_PORT
    print(f"Port not specified in configuration file '{config_file}' - setting default '{port}'")


app = FastAPI()
graphql_app = GraphQLRouter(schema)
app.include_router(graphql_app, prefix="/graphql")


def main() -> None:
    uvicorn.run(app, host=host, port=port)


if __name__ == "__main__":
    main()



import strawberry

from sqlalchemy.orm import Session
from typing import List, Optional

from omop_cdm_graphql.database import get_db
from omop_cdm_graphql.models import (
    Person as PersonModel,
    Observation as ObservationModel,
    ConditionOccurrence as ConditionModel,
)


@strawberry.type
class Observation:
    observation_id: int
    observation_concept_id: int
    observation_date: str


@strawberry.type
class ConditionOccurrence:
    condition_occurrence_id: int
    condition_concept_id: int
    condition_start_date: str


@strawberry.type
class Person:
    person_id: int
    gender_concept_id: int
    birth_datetime: str
    observations: List[Observation]
    conditions: List[ConditionOccurrence]


@strawberry.type
class Query:
    @strawberry.field
    def person(self, person_id: int) -> Optional[Person]:
        db: Session = next(get_db())
        db_person = (
            db.query(PersonModel).filter(PersonModel.person_id == person_id).first()
        )
        if not db_person:
            return None
        return Person(
            person_id=db_person.person_id,
            gender_concept_id=db_person.gender_concept_id,
            birth_datetime=db_person.birth_datetime.isoformat(),
            observations=[
                Observation(
                    observation_id=o.observation_id,
                    observation_concept_id=o.observation_concept_id,
                    observation_date=o.observation_date.isoformat(),
                )
                for o in db_person.observations
            ],
            conditions=[
                ConditionOccurrence(
                    condition_occurrence_id=c.condition_occurrence_id,
                    condition_concept_id=c.condition_concept_id,
                    condition_start_date=c.condition_start_date.isoformat(),
                )
                for c in db_person.conditions
            ],
        )

    @strawberry.field
    def all_persons(self) -> List[Person]:
        db: Session = next(get_db())
        db_persons = db.query(PersonModel).all()
        return [
            Person(
                person_id=p.person_id,
                gender_concept_id=p.gender_concept_id,
                birth_datetime=p.birth_datetime.isoformat(),
                observations=[
                    Observation(
                        observation_id=o.observation_id,
                        observation_concept_id=o.observation_concept_id,
                        observation_date=o.observation_date.isoformat(),
                    )
                    for o in p.observations
                ],
                conditions=[
                    ConditionOccurrence(
                        condition_occurrence_id=c.condition_occurrence_id,
                        condition_concept_id=c.condition_concept_id,
                        condition_start_date=c.condition_start_date.isoformat(),
                    )
                    for c in p.conditions
                ],
            )
            for p in db_persons
        ]


schema = strawberry.Schema(query=Query)



from sqlalchemy.orm import Session
from datetime import datetime

from omop_cdm_graphql.models import Base, Person, Observation, ConditionOccurrence
from omop_cdm_graphql.database import engine, get_db


Base.metadata.create_all(engine)


# Function to populate the database with more records
def populate_db():
    db: Session = next(get_db())

    # Additional Persons
    persons = [
        Person(
            person_id=1, gender_concept_id=8507, birth_datetime=datetime(1990, 1, 1)
        ),
        Person(
            person_id=2, gender_concept_id=8532, birth_datetime=datetime(1985, 5, 15)
        ),
        Person(
            person_id=3, gender_concept_id=8507, birth_datetime=datetime(1978, 3, 22)
        ),  # Male
        Person(
            person_id=4, gender_concept_id=8532, birth_datetime=datetime(1995, 7, 10)
        ),  # Female
        Person(
            person_id=5, gender_concept_id=8507, birth_datetime=datetime(1982, 11, 30)
        ),  # Male
        Person(
            person_id=6, gender_concept_id=8532, birth_datetime=datetime(2000, 4, 15)
        ),  # Female
    ]

    # Additional Observations
    observations = [
        Observation(
            observation_id=1,
            person_id=1,
            observation_concept_id=123,
            observation_date=datetime(2023, 1, 1),
        ),
        Observation(
            observation_id=2,
            person_id=2,
            observation_concept_id=124,
            observation_date=datetime(2023, 3, 15),
        ),
        Observation(
            observation_id=3,
            person_id=3,
            observation_concept_id=125,
            observation_date=datetime(2022, 12, 10),
        ),
        Observation(
            observation_id=4,
            person_id=4,
            observation_concept_id=126,
            observation_date=datetime(2023, 5, 20),
        ),
        Observation(
            observation_id=5,
            person_id=5,
            observation_concept_id=127,
            observation_date=datetime(2023, 1, 25),
        ),
        Observation(
            observation_id=6,
            person_id=6,
            observation_concept_id=128,
            observation_date=datetime(2023, 6, 1),
        ),
        Observation(
            observation_id=7,
            person_id=1,
            observation_concept_id=129,
            observation_date=datetime(2023, 7, 10),
        ),  # Second obs for person 1
    ]

    # Additional Condition Occurrences
    conditions = [
        ConditionOccurrence(
            condition_occurrence_id=1,
            person_id=1,
            condition_concept_id=456,
            condition_start_date=datetime(2023, 2, 1),
        ),
        ConditionOccurrence(
            condition_occurrence_id=2,
            person_id=2,
            condition_concept_id=457,
            condition_start_date=datetime(2023, 4, 1),
        ),
        ConditionOccurrence(
            condition_occurrence_id=3,
            person_id=3,
            condition_concept_id=458,
            condition_start_date=datetime(2022, 11, 15),
        ),
        ConditionOccurrence(
            condition_occurrence_id=4,
            person_id=4,
            condition_concept_id=459,
            condition_start_date=datetime(2023, 6, 5),
        ),
        ConditionOccurrence(
            condition_occurrence_id=5,
            person_id=5,
            condition_concept_id=460,
            condition_start_date=datetime(2023, 2, 10),
        ),
        ConditionOccurrence(
            condition_occurrence_id=6,
            person_id=6,
            condition_concept_id=461,
            condition_start_date=datetime(2023, 7, 15),
        ),
        ConditionOccurrence(
            condition_occurrence_id=7,
            person_id=1,
            condition_concept_id=462,
            condition_start_date=datetime(2023, 8, 20),
        ),  # Second condition for person 1
    ]
    # Add to the session and commit
    db.add_all(persons + observations + conditions)
    db.commit()
    print("Database populated with records!")


def main() -> None:
    # Ensure tables exist
    Base.metadata.create_all(engine)
    populate_db()


# Run the population script
if __name__ == "__main__":
    main()
